# Wayload

payload bind and extract module by W4lk3r.
#
Created by W4lk3r with Python3.

# Bind Payload Example

```python
from Wayload.hide import hd

hd(target_file_name, payload_name)

```

# Extract from apk Example


```python
from Wayload.extract import apk

apk(payload_hided_apk's_name, new_file_name_for_hided_payload)

```

# Extract from png Example


```python
from Wayload.extract import png

png(payload_hided_png's_name, new_file_name_for_hided_payload)

```

# Extract from jpg Example


```python
from Wayload.extract import jpg

jpg(payload_hided_jpg's_name, new_file_name_for_hided_payload)

```

# Extract from jpeg Example


```python
from Wayload.extract import jpeg

jpeg(payload_hided_jpeg's_name, new_file_name_for_hided_payload)

```

# Extract from gif Example


```python
from Wayload.extract import gif

gif(payload_hided_gif's_name, new_file_name_for_hided_payload)

```
